@@ -22,7 +22,7 @@ from clu.predicates import (typeof,
                             isexpandable, iscontainer, isnotnone,
                             always, uncallable)
 
-from clu.typology import iterlen, ismapping
+from clu.typology import iterlen, ishashablelist, ismapping
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -164,14 +164,26 @@ class FrozenKeyMap(FrozenKeyMapBase):
     
     def submap(self, *namespaces, unprefixed=False):
         """ Return a flattened dict containing only the namespaced items. """
+        # Get the frozen version of this class:
         cls = freeze_class(type(self))
+        
+        # Shortcut for unprefixed keys:
         if unprefixed:
-            return cls({ nskey : self[nskey] for nskey in self if NAMESPACE_SEP not in nskey })
+            return cls({ nskey : self[nskey] \
+                     for nskey in self \
+                      if NAMESPACE_SEP not in nskey })
+        
+        # Shortcut for a lack of namespaces:
         if not namespaces:
             return cls(self)
-        out = dict()
+        
+        # Iterate namespaces, taking those matching our namespaces
+        # for a new instance:
+        out = {}
         for namespace in namespaces:
-            out.update({ nskey : self[nskey] for nskey in self if nskey.startswith(namespace) })
+            out.update({ nskey : self[nskey] \
+                     for nskey in self \
+                      if nskey.startswith(namespace) })
         return cls(out)
     
     def keys(self, *namespaces, unprefixed=False):
@@ -205,7 +217,9 @@ class FrozenKeyMap(FrozenKeyMapBase):
         return hash(tuple(self.keys())) ^ len(self)
     
     def _get_namespace_foset(self):
-        return FlatOrderedSet(get_ns(nskey) for nskey in sorted(self) if NAMESPACE_SEP in nskey)
+        return FlatOrderedSet(get_ns(nskey) \
+            for nskey in self \
+             if NAMESPACE_SEP in nskey)
     
     def namespaces(self):
         yield from self._get_namespace_foset()
@@ -374,10 +388,12 @@ class NamespaceWalker(FrozenKeyMap):
         if cls is None:
             from clu.config.keymap import FrozenFlat
             cls = FrozenFlat
-        return cls({ pack_ns(key, *fragments) : value for *fragments, key, value in self.walk() })
+        return cls({ pack_ns(key, *fragments) : value \
+            for *fragments, key, value in self.walk() })
     
     def _get_namespace_foset(self):
-        return FlatOrderedSet(concatenate_ns(*fragments) for *fragments, _, _ in self.walk() if fragments)
+        return FlatOrderedSet(concatenate_ns(*fragments) \
+            for *fragments, _, _ in self.walk() if fragments)
     
     def keys(self, *namespaces, unprefixed=False):
         """ Return a namespaced view over either all keys in the mapping,
@@ -435,7 +451,8 @@ class NamespaceWalker(FrozenKeyMap):
 class FlatOrderedSet(collections.abc.Set,
                      collections.abc.Sequence,
                      collections.abc.Reversible,
-                     collections.abc.Hashable, clu.abstract.Cloneable,
+                     collections.abc.Hashable, clu.abstract.Appreciative,
+                                               clu.abstract.Cloneable,
                                                clu.abstract.ReprWrapper,
                                                clu.abstract.Serializable,
                                                metaclass=clu.abstract.Slotted):
@@ -476,11 +493,13 @@ class FlatOrderedSet(collections.abc.Set,
     @classmethod
     def from_dict(cls, instance_dict):
         """ Used by `clu.config.codecs` to deserialize FlatOrderedSets """
-        return cls(*instance_dict['things'],
-                    predicate=qualified_import(instance_dict['predicate']))
+        out = cls()
+        out.things = tuple(instance_dict['things'])
+        out.predicate = qualified_import(instance_dict['predicate'])
+        return out
     
     @classmethod
-    def is_a(cls, instance):
+    def appreciates(cls, instance):
         """ Check to see if a thing – an instance, whatever – is, like,
             close enough to what “this class” is to be a viable enough
             thing that way. Erm. Like it can be a FlatOrderedSet or whatever
@@ -498,7 +517,7 @@ class FlatOrderedSet(collections.abc.Set,
         """ Go through a list-like containerful of things, and if any of
             those is a container just like we are, expand it in place –
             recursively, of course, so everything can be nested as fuck
-            for all we care (q.v. “FlatOrderedSet::is_a(…)” doc supra).
+            for all we care (q.v. “FlatOrderedSet::appreciates(…)” doc supra).
             
         """
         # Set up a set of everything “seen”, which we pass forward
@@ -508,7 +527,7 @@ class FlatOrderedSet(collections.abc.Set,
         # Step through the non-None things we were given, preserving
         # their order:
         for thing in filter(None, things):
-            if cls.is_a(thing):
+            if cls.appreciates(thing):
                 # Are they “us”? If so, recursively expand them:
                 yield from cls.expand(*thing, seen=thingseen, predicate=predicate)
             
@@ -537,6 +556,10 @@ class FlatOrderedSet(collections.abc.Set,
             elif iscontainer(things[0]) and not ismapping(things[0]):
                 things = tuple(things[0])
         
+        # Make sure the things passed in can be worked with:
+        if not ishashablelist(things):
+            raise ValueError("FlatOrderedSet requires hashable members")
+        
         # Install a flat, uniquified version of what we were passed
         self.things = tuple(self.expand(*things, predicate=predicate))
         self.predicate = predicate
@@ -571,28 +594,28 @@ class FlatOrderedSet(collections.abc.Set,
         return self._hash()
     
     def __eq__(self, other):
-        if type(self).is_a(other):
+        if type(self).appreciates(other):
             return self.things == other.things
         elif isinstance(other, collections.abc.Sequence):
             return self.things == tuple(other)
         return NotImplemented
     
     def __ne__(self, other):
-        if type(self).is_a(other):
+        if type(self).appreciates(other):
             return self.things != other.things
         elif isinstance(other, collections.abc.Sequence):
             return self.things != tuple(other)
         return NotImplemented
     
     def __add__(self, operand):
-        if type(self).is_a(operand):
+        if type(self).appreciates(operand):
             return type(self)(*self.things, *operand.things, predicate=self.predicate)
         elif isinstance(operand, collections.abc.Sequence):
             return type(self)(*self.things, *tuple(operand), predicate=self.predicate)
         return NotImplemented
     
     def __radd__(self, operand):
-        if type(self).is_a(operand):
+        if type(self).appreciates(operand):
             return type(self)(*operand.things, *self.things, predicate=self.predicate)
         elif isinstance(operand, collections.abc.Sequence):
             return type(self)(*tuple(operand), *self.things, predicate=self.predicate)
@@ -608,14 +631,10 @@ class FlatOrderedSet(collections.abc.Set,
                                  predicate=self.predicate)
     
     def clone(self, deep=False, memo=None):
-        # Q.v. https://stackoverflow.com/a/48550898/298171
-        cls = type(self)
-        out = cls.__new__(cls)
-        things = list()
         copier = getattr(copy, deep and 'deepcopy' or 'copy')
-        for thing in self.things:
-            things.append(copier(thing))
-        super(cls, out).__init__(*things, predicate=self.predicate)
+        out = type(self)()
+        out.things = copier(self.things)
+        out.predicate = self.predicate
         return out
     
     def inner_repr(self):
