@@ -8,6 +8,8 @@ iterchain = chain.from_iterable
 import clu.abstract
 import collections
 import collections.abc
+import copy
+import multidict
 import sys
 
 from clu.constants.consts import STRINGPAIR, WHITESPACE, NoDefault
@@ -106,10 +108,7 @@ class ChainRepr(Repr):
         """ Initialize a ChainRepr, with default params
             for ‘maxlevel’, ‘maxstring’, and ‘maxother’.
         """
-        try:
-            super().__init__(*args, **kwargs)
-        except TypeError:
-            super().__init__()
+        super().__init__(*args, **kwargs)
         self.maxlevel = maxlevel
         self.maxstring = maxstring
         self.maxother = maxother
@@ -259,6 +258,7 @@ cmshortrepr = reprizer.shortrepr
 
 @export
 class ChainMap(collections.abc.MutableMapping,
+               clu.abstract.Appreciative,
                clu.abstract.Cloneable,
                metaclass=clu.abstract.Slotted):
     
@@ -281,7 +281,7 @@ class ChainMap(collections.abc.MutableMapping,
         return cls((dict(iterable) for iterable in iterables), **overrides)
     
     @classmethod
-    def is_a(cls, instance):
+    def appreciates(cls, instance):
         """ Check if an instance is a ChainMap of any sort – this covers:
             
             • this class (whichever it may be, derived or otherwise)
@@ -306,7 +306,7 @@ class ChainMap(collections.abc.MutableMapping,
         maps = []
         cls = type(self)
         for d in dicts:
-            if cls.is_a(d):
+            if cls.appreciates(d):
                 for mapping in d.maps:
                     if mapping not in maps:
                         maps.append(mapping)
@@ -452,14 +452,13 @@ class ChainMap(collections.abc.MutableMapping,
     
     def clone(self, deep=False, memo=None):
         """ Return a cloned copy of the ChainMap instance """
-        from copy import copy, deepcopy
-        cls = type(self)
-        if not deep:
-            return cls(copy(self.top),
-                           *self.rest)
-        return cls(deepcopy(self.top),
-                 *(deepcopy(mapping) for mapping in self.rest))
+        copier = deep and copy.deepcopy or copy.copy
+        return type(self)(*map(copier, self.maps))
 
+# “';p[[[[[-0” – Moira Rose
+
+@export
+@multidict.MutableMultiMapping.register # Must be a virtual ABC, bases don’t align
 class ChainMapPlusPlus(ChainMap):
     
     """ ChainMapPlusPlus – experimental extensions to the CLU ChainMap
@@ -469,8 +468,8 @@ class ChainMapPlusPlus(ChainMap):
         for our ever-popular and family-fun class “FlatOrderedSet”. Yes!
         
         In this case “experimental” is no joke. This is never guaranteed
-        to do anything expectedly or in anyway normal, anywhere, anytime,
-        for any of you. It’s not even @exported, see? If it works for you
+        to do anything expectedly or in any way normal, anywhere, anytime,
+        for any of you. It’s highly unrecommended. If it works for you
         I would looooooooove to know all about how, where, when – most of
         all *why* – and I’ll buy you a pizza, if you do alert me to all
         or at least some of these.
@@ -487,7 +486,7 @@ class ChainMapPlusPlus(ChainMap):
         """
         dictseen = seen or list()
         for mapping in filter(None, dicts):
-            if cls.is_a(mapping):
+            if cls.appreciates(mapping):
                 yield from cls.expand(*mapping.maps, seen=dictseen)
             else:
                 if mapping not in dictseen:
@@ -507,10 +506,36 @@ class ChainMapPlusPlus(ChainMap):
         
         # Just deal with the overrides:
         if overrides:
-            self.maps.insert(0, dict(overrides))
+            dicts.insert(0, dict(overrides))
         
         # The action (recursive, I might add) is all right here:
         self.maps.extend(self.expand(*dicts))
+    
+    def getone(self, key, default=NoDefault):
+        """ Return the first value for a key. """
+        return self.get(key, default)
+    
+    def getall(self, key, default=NoDefault):
+        """ Return all values for a key. """
+        from clu.predicates import item_across
+        if default is NoDefault:
+            return item_across(key, *self.dicts) or self.__missing__(key)
+        return item_across(key, *self.dicts, default=default)
+    
+    def add(self, key, value):
+        pass
+    
+    def extend(self, iter):
+        pass
+    
+    def update(self, dictish=NoDefault, **updates):
+        pass
+    
+    def popone(self, key, default=NoDefault):
+        pass
+    
+    def popall(self, key, default=tuple()):
+        pass
 
 @export
 def ischainmap(thing):
@@ -921,4 +946,4 @@ def test():
     return inline.test(100)
 
 if __name__ == '__main__':
-    sys.exit(test())
\ No newline at end of file
+    sys.exit(test())
